﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Collections.ObjectModel;

using MindFusion.Charting;
using MindFusion.Charting.WinForms;

namespace CustomData
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
			
			bubbleChart.Series = GetSeriesCollection();
			bubbleChart.Dock = DockStyle.Fill;
			bubbleChart.Title = "Patient BM Index by Age";
			bubbleChart.Plot.Background = new MindFusion.Drawing.SolidBrush(Color.White);

			bubbleChart.XAxis.MinValue = 0;
			bubbleChart.XAxis.MaxValue = 80;
			bubbleChart.XAxis.Title = "Age";
			bubbleChart.YAxis.MinValue = 0;
			bubbleChart.YAxis.MaxValue = 250;
			bubbleChart.YAxis.Title = "Weight";

			bubbleChart.Theme.CommonSeriesFills = bubbleChart.Theme.CommonSeriesStrokes = new List<MindFusion.Drawing.Brush>
			{
				new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, 90, 121, 165)),
				new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, 206, 0, 0))
				
			};

			bubbleChart.LegendHorizontalAlignment = MindFusion.Charting.Components.LayoutAlignment.Far;
			bubbleChart.Theme.LegendBackground = new MindFusion.Drawing.SolidBrush(Color.FromArgb(230, 230, 230));
			bubbleChart.Theme.LegendBorderStroke = new MindFusion.Drawing.SolidBrush(Color.LightGray);
			bubbleChart.Theme.HighlightStroke = new MindFusion.Drawing.SolidBrush(Color.White);
			bubbleChart.GridType = GridType.Horizontal;
			bubbleChart.Theme.GridLineStyle = System.Drawing.Drawing2D.DashStyle.Dash;
			bubbleChart.ShowLegendTitle = false;
			bubbleChart.AllowMoveLegend = false;

			bubbleChart.Theme.TitleFontSize = 12;
			bubbleChart.Theme.TitleFontStyle = FontStyle.Underline;
		}

		private ObservableCollection<Series> GetSeriesCollection()
		{
			ObservableCollection<Series> collection = new ObservableCollection<Series>();
			for (int i = 0; i < 3; i++)
			{
				if (i == 0)
				{
					collection.Add(new PatientSeries(
						new Patient[] {
							new Patient("Adams", 15, 70, "BMI > 25"),
							new Patient("Byrnes", 4, 20, "BMI > 25"),
							new Patient("Clyde", 25, 95, "BMI > 25"),
							new Patient("Davis", 32, 108, "BMI > 25"),
							new Patient("Evans", 51, 83, "BMI > 25")
						}));
				}
				if (i == 1)
				{
					collection.Add(new PatientSeries(
						new Patient[] {
							new Patient("Fox", 35, 180, "BMI > 30"),
							new Patient("Gene", 14, 77, "BMI > 30"),
							new Patient("Harold", 7, 65, "BMI > 30"),
							new Patient("Ian", 48, 125, "BMI > 30"),
							new Patient("James", 67, 98, "BMI > 30")
						}));
				}
			}
			return collection;
		}
	}

	public class Patient
	{
		public Patient(string name, float age, float weight, string bmindex)
		{
			Name = name;
			Age = age;
			Weight = weight;
			BMIndex = bmindex;
		}

		public string Name { get; set; }

		public float Age { get; set; }

		public float Weight { get; set; }

		public string BMIndex { get; set; }
	}

	public class PatientSeries : Series
	{
		public PatientSeries(IList<Patient> patients)
		{
			values = patients;
		}

		public double GetValue(int index, int dimension)
		{
			if (dimension == 0)
				return values[index].Age;
			else
				return values[index].Weight;
		}

		public string GetLabel(int index, LabelKinds kind)
		{
			if (kind == LabelKinds.InnerLabel)
				return values[index].Name;
			if (kind == LabelKinds.ToolTip)
				return values[index].Name + "(" + values[index].BMIndex + ")";

			return null;
		}

		public bool IsSorted(int dimension)
		{
			return false;
		}

		public bool IsEmphasized(int index)
		{
			return false;
		}

		public int Size
		{
			get { return values.Count; }
		}

		public int Dimensions
		{
			get { return 3; }
		}

		public string Title
		{
			get { return values[0].BMIndex; }
		}

		public LabelKinds SupportedLabels
		{
			get { return LabelKinds.InnerLabel | LabelKinds.ToolTip; }
		}

		public event EventHandler DataChanged;

		IList<Patient> values;
	}
}